<?php

if ( version_compare( $GLOBALS['wp_version'], '6.2', '<' ) ) {
	require get_template_directory() . '/includes/back-compat.php';
}

load_theme_textdomain( 'dealer', get_template_directory() . '/languages' );

if ( ! function_exists( 'dealer_set_up' ) ) :
    function dealer_set_up() {
		$color_scheme             = dealer_get_color_scheme();
		
		add_theme_support( 'title-tag' );
		// custom logo
		add_theme_support( 'custom-logo', array(
	    	'height'      => 240,
	    	'width'       => 600,
	    	'flex-height' => true,
    	) );
		
		// custom ukuran slide
		if ( get_theme_mod('slide_width') != "" ) {
			$swidth = get_theme_mod('slide_width');
	    } else {
			$swidth = 1200;
		}
		if ( get_theme_mod('slide_height') != "" ) {
			$sheight = get_theme_mod('slide_height');
		} else {
		    $sheight = 600;
	    }
	    add_theme_support('post-thumbnails');
	    add_image_size('slider', $swidth, $sheight, true);
	    add_image_size('landscape', 600, 400, true);
	    add_image_size('square', 100, 75, true);
		add_image_size('medscape', 300, 200, true);
	    add_image_size('litescape', 210, 140, true);
	    add_image_size('little', 180, 120, true);
		add_image_size('mini', 50, 50, true);
		
		// menambahkan menu navigasi
		register_nav_menus(array(
	    	'navigation' => __('Tampilkan Menu ini di Navigasi Header', 'dealer'),
    	));
		add_theme_support('html5', array(
	    	'search-form', 'comment-form', 'comment-list',
    	));
		
		add_theme_support( 'customize-selective-refresh-widgets' );
		add_theme_support( 'responsive-embeds' );
		add_theme_support( 'automatic-feed-links' );
    }
endif; // dealer_set_up
add_action( 'after_setup_theme', 'dealer_set_up' );

function ciussnews_content_width() {
	$GLOBALS['content_width'] = apply_filters( 'ciussnews_content_width', 840 );
}
add_action( 'after_setup_theme', 'ciussnews_content_width', 0 );

/*
 * Register widget (sidebar).
 */
function dealer_widgets_init() {

	register_sidebar(array(
		'name' => __('Sidebar Utama', 'dealer'),
		'id'   => 'sidebar-1',
		'before_widget' => '<div id="%1$s" class="%2$s widget">',
		'after_widget' => '</div>',
		'before_title' => '<h3>',
		'after_title' => '</h3>'
	));
	
}
add_action('widgets_init', 'dealer_widgets_init');

show_admin_bar(false);

function return_30( $seconds ) {
  return 120;
}
add_filter( 'wp_feed_cache_transient_lifetime' , 'return_30' ); 
 
function dealer_stylescripts() {
	$refresh = date_i18n("His");
	wp_enqueue_style('dealer-style', get_stylesheet_uri(), array(), $refresh );
	if ( get_theme_mod('layout_mode') != "" ) {
		wp_enqueue_style('dealer-css', get_template_directory_uri() .'/'. get_theme_mod('layout_mode') .'/style.css', array(), $refresh );
	} else {
		wp_enqueue_style('dealer-css', get_template_directory_uri() .'/dealer/style.css', array(), $refresh );
	}
	wp_enqueue_style('dealer-splide', get_template_directory_uri().'/stylesheet/splide.min.css', array(), $refresh );
	wp_enqueue_style('dealer-font', get_template_directory_uri().'/stylesheet/dealer-font.css', array(), $refresh );
	wp_enqueue_style('dealer-ico', get_template_directory_uri().'/stylesheet/icofont.css', array(), $refresh );
}
add_action('wp_enqueue_scripts', 'dealer_stylescripts');

function admin_customizercss() {
	$refresh = date_i18n("His");
    wp_register_style( 'customizer_css', get_template_directory_uri() . '/stylesheet/customizer.css', false, $refresh );
    wp_enqueue_style( 'customizer_css' );
}
add_action( 'admin_enqueue_scripts', 'admin_customizercss' );

function dealer_scripts() {
	if (is_singular() && comments_open() && get_option('thread_comments')) {
		wp_enqueue_script('comment-reply');
	}
	$refresh = date_i18n("His");
	wp_enqueue_script( 'jquery' );
	wp_enqueue_script( 'dealer-splide', get_template_directory_uri() . '/javascript/splide.min.js', array(), false, true );
	wp_enqueue_script( 'dealer-footer', get_template_directory_uri() . '/javascript/footer.js', array(), $refresh, true );
	if ( get_theme_mod('banner_option') == "once" ) {
    	wp_enqueue_script( 'dealer-popup', get_template_directory_uri() . '/javascript/dealer-popup.js', array(), false, true );
	}
	
}
add_action('wp_footer', 'dealer_scripts');

// Defer Jacascript
function defer_parsing_of_js ( $url ) {
	if ( FALSE === strpos( $url, '.js' ) ) {
		return $url;
	}
	if ( strpos( $url, 'jquery.js' ) ) {
		return $url;
	}
	return $url .'" async="async';
}
add_filter( 'clean_url', 'defer_parsing_of_js', 11, 1 );

// Preload Stylesheet
function preload_for_css ( $html, $handle, $href, $media ) {
    if ( is_admin () ) {
        return $html;
    }
    echo '<link rel="stylesheet preload" as="style" href="' . $href . '" media="all">';
}
add_filter ( 'style_loader_tag', 'preload_for_css', 10, 4 );

// Remove Lazy Load
function my_no_loading_filter( $attr, $attachment, $size ) {
  unset( $attr['loading'] );
  return $attr;
}
add_filter( 'wp_get_attachment_image_attributes', 'my_no_loading_filter', 10, 3 );

require get_template_directory() . '/includes/template-tags.php';
require get_template_directory() . '/includes/customizer.php';
require get_template_directory() . '/includes/element-refresh.php';
require get_template_directory() . '/includes/custom-fonts.php';

require get_template_directory() . '/includes/coloring.php';
require get_template_directory() . '/includes/color-option.php';
require get_template_directory() . '/includes/color-enqueue.php';
require get_template_directory() . '/includes/color-print.php';
require get_template_directory() . '/includes/color-print-footer.php';
require get_template_directory() . '/includes/color-inline-css.php';

require get_template_directory() . '/includes/func/dealer-breadcrumb.php';
require get_template_directory() . '/includes/func/dealer-ciuss-news.php';


if (is_admin() && isset($_GET['activated']) && $pagenow == 'themes.php') {
	update_option('posts_per_page', 9);
}

function dealer_numeric_pagination() {

	if( is_singular() )
		return;
	global $wp_query;

	if( $wp_query->max_num_pages <= 1 )
		return;

	$paged = get_query_var( 'paged' ) ? absint( get_query_var( 'paged' ) ) : 1;
	$max   = intval( $wp_query->max_num_pages );
	if ( $paged >= 1 )
		$links[] = $paged;
	if ( $paged >= 3 ) {
		$links[] = $paged - 1;
		$links[] = $paged - 2;
	}

	if ( ( $paged + 2 ) <= $max ) {
		$links[] = $paged + 2;
		$links[] = $paged + 1;
	}

	if ( ! in_array( 1, $links ) ) {
		$class = 1 == $paged ? ' class="active"' : '';
		printf( '<a%s href="%s">%s</a>' . "\n", $class, esc_url( get_pagenum_link( 1 ) ), '1' );
		if ( ! in_array( 2, $links ) )
			echo ' … ';
	}

	sort( $links );
	foreach ( (array) $links as $link ) {
		$class = $paged == $link ? ' class="active"' : '';
		printf( '<a%s href="%s">%s</a>' . "\n", $class, esc_url( get_pagenum_link( $link ) ), $link );
	}

	if ( ! in_array( $max, $links ) ) {
		if ( ! in_array( $max - 1, $links ) )
			echo ' … ' . "\n";
		$class = $paged == $max ? ' class="active"' : '';
		printf( '<a%s href="%s">%s</a>' . "\n", $class, esc_url( get_pagenum_link( $max ) ), $max );
	}

}

function shapeSpace_popular_posts($post_id) {
	$count_key = 'popular_posts';
	$count = get_post_meta($post_id, $count_key, true);
	if ($count == '') {
		$count = 0;
		delete_post_meta($post_id, $count_key);
		add_post_meta($post_id, $count_key, '0');
	} else {
		$count++;
		update_post_meta($post_id, $count_key, $count);
	}
}
function shapeSpace_track_posts($post_id) {
	if (!is_single()) return;
	if (empty($post_id)) {
		global $post;
		$post_id = $post->ID;
	}
	shapeSpace_popular_posts($post_id);
}
add_action('wp_head', 'shapeSpace_track_posts');

function getPostViews($postID){ 
    $count_key = 'post_views_count'; 
	$count = get_post_meta($postID, 
	$count_key, true); 
	
	if($count==''){ 
	delete_post_meta($postID, $count_key); 
	add_post_meta($postID, $count_key, '0'); return "0"; 
	} 
	return $count; 
} 
	
function setPostViews($postID) { 
    $count_key = 'post_views_count'; 
	$count = get_post_meta($postID, $count_key, true); 
	
	if($count==''){ 
	$count = 0; delete_post_meta($postID, $count_key); 
	add_post_meta($postID, $count_key, '0'); 
	}else{ 
	$count++; 
	update_post_meta($postID, $count_key, $count); 
	} 
}

function dealer_thumbnail( $full, $id, $size ) {
    if ( ! is_admin() || ! get_current_screen() || 'slider' !==   get_current_screen()->post_type ) {
        return $full;
    }
	
	remove_filter( 'image_downsize', __FUNCTION__, 10, 3 );
	$image = image_downsize( $id, 'slider' ); 
	
	add_filter( 'image_downsize', __FUNCTION__, 10, 3 );
	
	return $image;
}
add_filter( 'image_downsize', 'dealer_thumbnail', 10, 3 );

class Menu_With_Description extends Walker_Nav_Menu {
    function start_el( &$output, $item, $depth = 0, $args = array(), $id = 0 ) {
        global $wp_query;

        $indent = ( $depth ) ? str_repeat( "\t", $depth ) : '';
        $class_names = $value = '';
        $classes = empty( $item->classes ) ? array() : (array) $item->classes;
        $class_names = join( ' ', apply_filters( 'nav_menu_css_class', array_filter( $classes ), $item ) );
        $class_names = ' class="' . esc_attr( $class_names ) . '"';

        $output .= $indent . '<li id="menu-item-'. $item->ID . '"' . $value . $class_names .'>';

        $attributes  = ! empty( $item->attr_title ) ? ' title="'  . esc_attr( $item->attr_title ) .'"' : '';
        $attributes .= ! empty( $item->target )     ? ' target="' . esc_attr( $item->target     ) .'"' : '';
        $attributes .= ! empty( $item->xfn )        ? ' rel="'    . esc_attr( $item->xfn        ) .'"' : '';
        $attributes .= ! empty( $item->url )        ? ' href="'   . esc_attr( $item->url        ) .'"' : '';

        $attr_defaults = array( 'class' => 'navmenu_thumb' , 'alt' => esc_attr( $item->attr_title ) , 'title' => esc_attr( $item->attr_title ) );
        $attr = isset( $args->thumbnail_attr ) ? $args->thumbnail_attr : '';
        $attr = wp_parse_args( $attr , $attr_defaults );

        $item_output = $args->before;
        $item_output .= '<a'. $attributes .'>';

        // Cek apakah post_type adalah 'model' sebelum menampilkan thumbnail
        if ($depth == 1 && get_post_type($item->object_id) == 'model') {
            $item_output .= ( isset( $args->thumbnail_link ) && $args->thumbnail_link ) ? '<a' . $attributes . '>' : '';
            $item_output .= apply_filters( 'menu_item_thumbnail' , ( isset( $args->thumbnail ) && $args->thumbnail ) ? get_the_post_thumbnail( $item->object_id , ( isset( $args->thumbnail_size ) ) ? $args->thumbnail_size : 'little' , $attr ) : '' , $item , $args , $depth );       
            $item_output .= ( isset( $args->thumbnail_link ) && $args->thumbnail_link ) ? '</a>' : ''; 
        }
        
        $item_output .= $args->link_before . apply_filters( 'the_title', $item->title, $item->ID ) . $args->link_after;
        
        $item_output .= '</a>';
        $item_output .= $args->after;

        $output .= apply_filters( 'walker_nav_menu_start_el', $item_output, $item, $depth, $args );
    }
}
add_filter( 'wp_nav_menu_args' , 'my_add_menu_descriptions' );

function my_add_menu_descriptions( $args ) {
    $args['walker'] = new Menu_With_Description;
    $args['desc_depth'] = 1;
    $args['thumbnail'] = true;
    $args['thumbnail_link'] = false;
    $args['thumbnail_size'] = 'little';
    $args['thumbnail_attr'] = array( 'class' => 'navmenu_thumb my_thumb' , 'alt' => '' , 'title' => '' );

    return $args;
}

function gallery_featured_image($post_ID) {
    $post_thumbnail_id = get_post_thumbnail_id($post_ID);
    if ($post_thumbnail_id) {
        $post_thumbnail_img = wp_get_attachment_image_src($post_thumbnail_id, 'little');
        echo '<img width="180" src="' . $post_thumbnail_img[0] . '" />';
    }
}

function gallery_columns_head($defaults) {
    $defaults['featured_image'] = __( 'Gambar Produk', 'dealer' );
    return $defaults;
}
	
function gallery_columns_content($column_name, $post_ID) {
    if ($column_name == 'featured_image') {
        $post_featured_image = gallery_featured_image($post_ID);
        if ($post_featured_image) {
            echo '<img src="' . $post_featured_image . '" />';
        }
    }
}
	
add_filter('manage_model_posts_columns', 'gallery_columns_head', 10);
add_action('manage_model_posts_custom_column', 'gallery_columns_content', 10, 2);

function dealer_event_expired($post_ID) {
	global $post;
    $post_event_date = get_post_meta($post_ID, '_tevent', true);
	$end = get_post_meta($post_ID, '_tevent', true).' '.get_post_meta($post_ID, '_jam', true);
	$exp = strtotime(date_i18n($end));
	$dday = strtotime(date_i18n('d-m-Y H:i'));
	$sisa = $exp-$dday;
	$event_date = date("d F Y", strtotime($post_event_date));
    if ($post_event_date != "" ) {
        echo $event_date;
		if ( $sisa < 0 ) { 
			echo __( '<br/><strong class="expired">Agenda sudah lewat</strong>', 'dealer' ); 
		} else {
			echo __( '<br/><strong class="next">Agenda akan datang</strong>', 'dealer' );
		}
    }
}

function dealer_event_columns($defaults) {
    $defaults['dealer_expired'] = __( 'Tanggal Agenda', 'dealer' );
    return $defaults;
}
	
function event_columns_content($column_name, $post_ID) {
    if ($column_name == 'dealer_expired') {
		global $post;
        $post_expired_event = dealer_event_expired($post_ID);
		$end = get_post_meta($post_ID, '_tevent', true).' '.get_post_meta($post_ID, '_jam', true);
	    $exp = strtotime(date_i18n($end));
	    $dday = strtotime(date_i18n('d-m-Y H:i'));
	    $sisa = $exp-$dday;
		if ($post_expired_event != "" ) {
            echo $post_expired_event;
			if ( $sisa < 0 ) { echo __( '<br/><strong>Agenda sudah lewat</strong>', 'dealer' ); }
        }
    }
}
	
add_filter('manage_event_posts_columns', 'dealer_event_columns', 10);
add_action('manage_event_posts_custom_column', 'event_columns_content', 10, 2);

function smart_excerpt($content, $length = 30) {
    // Remove shortcodes
    $content = strip_shortcodes($content);
    
    // Remove HTML tags
    $content = strip_tags($content);
    
    // Trim content to specified length
    $excerpt = wp_trim_words($content, $length, '');

    return $excerpt;
}

function commentslist($comment, $args, $depth) {
	$GLOBALS['comment'] = $comment; 
	?>
	
	    <div class="dealer__clear comment__area">
		    <div class="comment__avatar">
		        <?php if(get_avatar($comment)) { ?>
					<?php echo get_avatar($comment, 80); ?>
				<?php } else { ?>
					<img src="<?php echo esc_url(get_template_directory_uri()); ?>/images/avatar.png"/>
				<?php } ?>
			</div>
			    <?php if ($comment->comment_approved == '0') { ?>
		         	<div class="comment__meta comment_unapproved">
					<p><?php echo __('Komentar menunggu moderasi admin.', 'dealer') ?></p>
				<?php } else { ?>
				    <div class="comment__meta">
				<?php } ?>
				<?php 
			    	printf(__('<div class="comment__author"><span>%s</span>, <em>%s</em></div>', 'dealer'), get_comment_author_link(), get_comment_date('l, j M Y'));
					comment_text();
					comment_reply_link(array_merge($args, array('depth' => $depth, 'max_depth' => $args['max_depth'])));
				?>
			</div>
		</div>
    <?php
}

function comments_link_attributes() {
	return 'class="comments_popup_link"';
}
add_filter('comments_popup_link_attributes', 'comments_link_attributes');

function next_posts_attributes() {
	return 'class="nextpostslink"';
}
add_filter('next_posts_link_attributes', 'next_posts_attributes');

function prev_posts_attributes() {
	return 'class="previouspostslink"';
}
add_filter('previous_posts_link_attributes', 'prev_posts_attributes');

$exl_posts = array();


/**
 * Change default screen title post_type.
 */
function dealer_title_text( $title ){
    $screen = get_current_screen();
    // Default screen title post_type Agenda
    if  ( 'event' == $screen->post_type ) {
        $title = __( 'Judul Agenda..', 'dealer' );
	} else if  ( 'testimoni' == $screen->post_type ) {
        $title = __( 'Tambahkan Nama..', 'dealer' );
    } else if  ( 'model' == $screen->post_type ) {
        $title = __( 'Tambah Model..', 'dealer' );
	} else if  ( 'slider' == $screen->post_type ) {
        $title = __( 'Tambah Slider..', 'dealer' );
	} else {
        $title = __( 'Tambah Judul..', 'dealer' );
    }
    return $title;
}
add_filter( 'enter_title_here', 'dealer_title_text' );

function dealer_facebook_pixel() {
		if ( get_theme_mod('dealer_pixel_code') != "" ) {
			?>
	        <!-- Meta Pixel Code -->
	        <script>
	        !function(f,b,e,v,n,t,s)
	        {if(f.fbq)return;n=f.fbq=function(){n.callMethod?
	        n.callMethod.apply(n,arguments):n.queue.push(arguments)};
	        if(!f._fbq)f._fbq=n;n.push=n;n.loaded=!0;n.version='2.0';
	        n.queue=[];t=b.createElement(e);t.async=!0;
	        t.src=v;s=b.getElementsByTagName(e)[0];
	        s.parentNode.insertBefore(t,s)}(window, document,'script',
	        'https://connect.facebook.net/en_US/fbevents.js');
	        fbq('init', '<?php echo esc_html( get_theme_mod('dealer_pixel_code') ); ?>');
	        fbq('track', 'PageView');
	        </script>
	        <noscript><img height="1" width="1" style="display:none" src="https://www.facebook.com/tr?id=<?php echo rawurlencode( get_theme_mod('maxx_pixel_code') ); ?>&ev=PageView&noscript=1" /></noscript>
            <!-- End Meta Pixel Code -->
			<?php
		}
}
add_action('wp_footer', 'dealer_facebook_pixel');

