/* global colorScheme, Color */
/**
 * Add a listener to the Color Scheme control to update other color controls to new values/defaults.
 * Also trigger an update of the Color Scheme CSS when a color is changed.
 */

( function( api ) {
	var cssTemplate = wp.template( 'dealer-color-scheme' ),
		colorSchemeKeys = [
			'dealer_bodybg',
			'dealer_bodycolor',
			'dealer_bodylink',
	    	'dealer_headbg',
	      	'dealer_headcol',
	    	'dealer_headlink',
	    	'dealer_headaccbg',
			'dealer_headacccol',
	    	'dealer_contbg',
	    	'dealer_contcol',
	    	'dealer_contacc',
	    	'dealer_runbg',
	    	'dealer_runcol',
	    	'dealer_runacc',
	    	'dealer_arcbg',
	    	'dealer_arccol',
	    	'dealer_arcacc',
	   	   	'dealer_arcpop',
	   		'dealer_arclim',
	   		'dealer_arcind',
	   		'dealer_arcpro',
	   		'dealer_arcbest',
			'dealer_singbg',
			'dealer_singbg2',
			'dealer_singcol',
			'dealer_singacc1',
			'dealer_singacc2',
			'dealer_singacc3',
	    	'dealer_footbg',
	    	'dealer_footcol',
	    	'dealer_footacc',
	    	'home_eventbg',
	    	'home_eventcol',
	    	'home_eventacc',
	    	'home_slidebg',
	    	'home_slidebgacc',
	     	'home_agenbg',
	    	'home_agencol',
	    	'home_agenacc',
	    	'home_listtop',
	     	'home_listbot',
	    	'home_gstbg',
	      	'home_gstbgacc',
	    	'home_gstbox',
	    	'home_gstcol',
	    	'home_gstacc',
		],
		colorSettings = [
			'dealer_bodybg',
			'dealer_bodycolor',
			'dealer_bodylink',
	    	'dealer_headbg',
	      	'dealer_headcol',
	    	'dealer_headlink',
	    	'dealer_headaccbg',
			'dealer_headacccol',
	    	'dealer_contbg',
	    	'dealer_contcol',
	    	'dealer_contacc',
	    	'dealer_runbg',
	    	'dealer_runcol',
	    	'dealer_runacc',
	    	'dealer_arcbg',
	    	'dealer_arccol',
	    	'dealer_arcacc',
	   	   	'dealer_arcpop',
	   		'dealer_arclim',
	   		'dealer_arcind',
	   		'dealer_arcpro',
	   		'dealer_arcbest',
			'dealer_singbg',
			'dealer_singbg2',
			'dealer_singcol',
			'dealer_singacc1',
			'dealer_singacc2',
			'dealer_singacc3',
	    	'dealer_footbg',
	    	'dealer_footcol',
	    	'dealer_footacc',
	    	'home_eventbg',
	    	'home_eventcol',
	    	'home_eventacc',
	    	'home_slidebg',
	    	'home_slidebgacc',
	     	'home_agenbg',
	    	'home_agencol',
	    	'home_agenacc',
	    	'home_listtop',
	     	'home_listbot',
	    	'home_gstbg',
	      	'home_gstbgacc',
	    	'home_gstbox',
	    	'home_gstcol',
	    	'home_gstacc',
		];

	api.controlConstructor.select = api.Control.extend( {
		ready: function() {
			if ( 'color_scheme' === this.id ) {
				this.setting.bind( 'change', function( value ) {
					var colors = colorScheme[value].colors;

					color = colors[1];
					api( 'dealer_bodybg' ).set( color );
					api.control( 'dealer_bodybg' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[2];
					api( 'dealer_bodycolor' ).set( color );
					api.control( 'dealer_bodycolor' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[3];
					api( 'dealer_bodylink' ).set( color );
					api.control( 'dealer_bodylink' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[4];
					api( 'dealer_headbg' ).set( color );
					api.control( 'dealer_headbg' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[5];
					api( 'dealer_headcol' ).set( color );
					api.control( 'dealer_headcol' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[6];
					api( 'dealer_headlink' ).set( color );
					api.control( 'dealer_headlink' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[7];
					api( 'dealer_headaccbg' ).set( color );
					api.control( 'dealer_headaccbg' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[8];
					api( 'dealer_headacccol' ).set( color );
					api.control( 'dealer_headacccol' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[9];
					api( 'dealer_contbg' ).set( color );
					api.control( 'dealer_contbg' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[10];
					api( 'dealer_contcol' ).set( color );
					api.control( 'dealer_contcol' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[11];
					api( 'dealer_contacc' ).set( color );
					api.control( 'dealer_contacc' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[12];
					api( 'dealer_runbg' ).set( color );
					api.control( 'dealer_runbg' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[13];
					api( 'dealer_runcol' ).set( color );
					api.control( 'dealer_runcol' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[14];
					api( 'dealer_runacc' ).set( color );
					api.control( 'dealer_runacc' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[15];
					api( 'dealer_arcbg' ).set( color );
					api.control( 'dealer_arcbg' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[16];
					api( 'dealer_arccol' ).set( color );
					api.control( 'dealer_arccol' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[17];
					api( 'dealer_arcacc' ).set( color );
					api.control( 'dealer_arcacc' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[18];
					api( 'dealer_arcpop' ).set( color );
					api.control( 'dealer_arcpop' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[19];
					api( 'dealer_arclim' ).set( color );
					api.control( 'dealer_arclim' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[20];
					api( 'dealer_arcind' ).set( color );
					api.control( 'dealer_arcind' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[21];
					api( 'dealer_arcpro' ).set( color );
					api.control( 'dealer_arcpro' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[22];
					api( 'dealer_arcbest' ).set( color );
					api.control( 'dealer_arcbest' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[23];
					api( 'dealer_singbg' ).set( color );
					api.control( 'dealer_singbg' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[24];
					api( 'dealer_singbg2' ).set( color );
					api.control( 'dealer_singbg2' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[25];
					api( 'dealer_singcol' ).set( color );
					api.control( 'dealer_singcol' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[26];
					api( 'dealer_singacc1' ).set( color );
					api.control( 'dealer_singacc1' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[27];
					api( 'dealer_singacc2' ).set( color );
					api.control( 'dealer_singacc2' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[28];
					api( 'dealer_singacc3' ).set( color );
					api.control( 'dealer_singacc3' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[29];
					api( 'dealer_footbg' ).set( color );
					api.control( 'dealer_footbg' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[30];
					api( 'dealer_footcol' ).set( color );
					api.control( 'dealer_footcol' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[31];
					api( 'dealer_footacc' ).set( color );
					api.control( 'dealer_footacc' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[32];
					api( 'home_eventbg' ).set( color );
					api.control( 'home_eventbg' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[33];
					api( 'home_eventcol' ).set( color );
					api.control( 'home_eventcol' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[34];
					api( 'home_eventacc' ).set( color );
					api.control( 'home_eventacc' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[35];
					api( 'home_slidebg' ).set( color );
					api.control( 'home_slidebg' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[36];
					api( 'home_slidebgacc' ).set( color );
					api.control( 'home_slidebgacc' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[37];
					api( 'home_agenbg' ).set( color );
					api.control( 'home_agenbg' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[38];
					api( 'home_agencol' ).set( color );
					api.control( 'home_agencol' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[39];
					api( 'home_agenacc' ).set( color );
					api.control( 'home_agenacc' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[40];
					api( 'home_listtop' ).set( color );
					api.control( 'home_listtop' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[41];
					api( 'home_listbot' ).set( color );
					api.control( 'home_listbot' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[42];
					api( 'home_gstbg' ).set( color );
					api.control( 'home_gstbg' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[43];
					api( 'home_gstbgacc' ).set( color );
					api.control( 'home_gstbgacc' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[44];
					api( 'home_gstbox' ).set( color );
					api.control( 'home_gstbox' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[45];
					api( 'home_gstcol' ).set( color );
					api.control( 'home_gstcol' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
						
					color = colors[46];
					api( 'home_gstacc' ).set( color );
					api.control( 'home_gstacc' ).container.find( '.color-picker-hex' )
						.data( 'data-default-color', color )
						.wpColorPicker( 'defaultColor', color );
					
				} );
			}
		}
	} );

	// Generate the CSS for the current Color Scheme.
	function updateCSS() {
		var scheme = api( 'color_scheme' )(),
			css,
			colors = _.object( colorSchemeKeys, colorScheme[ scheme ].colors );

		// Merge in color scheme overrides.
		_.each( colorSettings, function( setting ) {
			colors[ setting ] = api( setting )();
		} );

		// Add additional color.
		// jscs:disable
		colors.border_color = Color( colors.main_text_color ).toCSS( 'rgba', 0.2 );
		// jscs:enable

		css = cssTemplate( colors );

		api.previewer.send( 'update-color-scheme-css', css );
	}

	// Update the CSS whenever a color setting is changed.
	_.each( colorSettings, function( setting ) {
		api( setting, function( setting ) {
			setting.bind( updateCSS );
		} );
	} );
} )( wp.customize );
