<?php

/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://ciuss.com
 * @since             1.0.0
 * @package           Dealer Ciuss
 *
 * @wordpress-plugin
 * Plugin Name:       Dealer Library
 * Plugin URI:        https://ciuss.com
 * Description:       Dealer Library
 * Version:           1.2.8
 * Author:            Ciuss Creative
 * Author URI:        https://ciuss.com
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       dealerlibrary
 * Domain Path:       /languages
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'DEALER_VERSION', '1.2.8' );
define( 'DEALER_BASENAME', plugin_basename(__FILE__));
define( 'DEALER_PATH', plugin_dir_path( __FILE__ ) );
define( 'DEALER_URL', plugin_dir_url(__FILE__ ) );

include( dirname( __FILE__ ) . '/class-function.php' );
include( dirname( __FILE__ ) . '/includes/class-dealer-library-init.php' );

DealerCiussUpdater::init(__FILE__);

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-dealer-library-activator.php
 */
function activate_ciuss_dealer() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-dealer-library-activator.php';
	Dealer_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-dealer-library-deactivator.php
 */
function deactivate_ciuss_dealer() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-dealer-library-deactivator.php';
	Dealer_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_ciuss_dealer' );
register_deactivation_hook( __FILE__, 'deactivate_ciuss_dealer' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-dealer-library.php';


/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_ciuss_dealer() {

	$plugin = new Dealer();
	$plugin->run();

}
run_ciuss_dealer();
